@@ -7,13 +7,14 @@ use strict;
 
 package XML::Compile::XOP::Include;
 use vars '$VERSION';
-$VERSION = '3.18';
+$VERSION = '3.19';
 
 
 use Log::Report 'xml-compile-soap', syntax => 'SHORT';
 use XML::Compile::SOAP::Util qw/:xop10/;
 use HTTP::Message            ();
 use File::Slurp::Tiny        qw/read_file write_file/;
+use Encode                   qw/decode FB_CROAK/;
 
 
 use overload '""'     => 'content'
@@ -39,9 +40,10 @@ sub fromMime($)
 
     my $content = $http->decoded_content(ref => 1) || $http->content(ref => 1);
     $class->new
-     ( bytes => $content
-     , cid   => $cid
-     , type  => scalar $http->content_type
+     ( bytes   => $content
+     , cid     => $cid
+     , type    => scalar $http->content_type
+     , charset => scalar $http->content_type_charset
      );
 }
 
@@ -61,6 +63,18 @@ sub content(;$)
 }
 
 
+sub string() {
+	my $self = shift;
+    my $cs = $self->contentCharset || 'UTF-8';
+    decode $cs, $self->content, FB_CROAK;
+}
+
+
+sub contentType()    { shift->{type} }
+sub contentCharset() { shift->{charset} }
+
+#---------
+
 sub xmlNode($$$$)
 {   my ($self, $doc, $path, $tag) = @_;
     my $node = $doc->createElement($tag);
